<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Luminosità</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Impostazioni per retroilluminazione e luminosità:&lt;/span&gt;&lt;/p&gt;&lt;p&gt; Usare le frecce per modificare le impostazioni.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>Chiedi conferma per la modifica</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>Le impostazioni per la luminosità sono cambiate</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Richiesta conferma: Le impostazioni sono corrette?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translatorcomment>no idea where this appears</translatorcomment>
        <translation>&lt;b&gt;Output:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation>Click destro per resettare</translation>
    </message>
</context>
</TS>
